"""
Type annotations for cleanroomsml service type definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/type_defs/)

Usage::

    ```python
    from mypy_boto3_cleanroomsml.type_defs import S3ConfigMapTypeDef

    data: S3ConfigMapTypeDef = ...
    ```
"""

import sys
from datetime import datetime
from typing import Dict, List, Mapping, Sequence, Union

from .literals import (
    AudienceExportJobStatusType,
    AudienceGenerationJobStatusType,
    AudienceModelMetricTypeType,
    AudienceModelStatusType,
    AudienceSizeTypeType,
    ColumnTypeType,
    PolicyExistenceConditionType,
    SharedAudienceMetricsType,
    TagOnCreatePolicyType,
)

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "S3ConfigMapTypeDef",
    "AudienceSizeTypeDef",
    "StatusDetailsTypeDef",
    "AudienceGenerationJobSummaryTypeDef",
    "AudienceModelMetricTypeDef",
    "AudienceModelSummaryTypeDef",
    "AudienceSizeConfigTypeDef",
    "ColumnSchemaTypeDef",
    "TimestampTypeDef",
    "ResponseMetadataTypeDef",
    "GlueDataSourceTypeDef",
    "DeleteAudienceGenerationJobRequestRequestTypeDef",
    "DeleteAudienceModelRequestRequestTypeDef",
    "DeleteConfiguredAudienceModelPolicyRequestRequestTypeDef",
    "DeleteConfiguredAudienceModelRequestRequestTypeDef",
    "DeleteTrainingDatasetRequestRequestTypeDef",
    "GetAudienceGenerationJobRequestRequestTypeDef",
    "GetAudienceModelRequestRequestTypeDef",
    "GetConfiguredAudienceModelPolicyRequestRequestTypeDef",
    "GetConfiguredAudienceModelRequestRequestTypeDef",
    "GetTrainingDatasetRequestRequestTypeDef",
    "PaginatorConfigTypeDef",
    "ListAudienceExportJobsRequestRequestTypeDef",
    "ListAudienceGenerationJobsRequestRequestTypeDef",
    "ListAudienceModelsRequestRequestTypeDef",
    "ListConfiguredAudienceModelsRequestRequestTypeDef",
    "ListTagsForResourceRequestRequestTypeDef",
    "ListTrainingDatasetsRequestRequestTypeDef",
    "TrainingDatasetSummaryTypeDef",
    "PutConfiguredAudienceModelPolicyRequestRequestTypeDef",
    "TagResourceRequestRequestTypeDef",
    "UntagResourceRequestRequestTypeDef",
    "AudienceDestinationTypeDef",
    "AudienceGenerationJobDataSourceTypeDef",
    "RelevanceMetricTypeDef",
    "StartAudienceExportJobRequestRequestTypeDef",
    "AudienceExportJobSummaryTypeDef",
    "CreateAudienceModelRequestRequestTypeDef",
    "CreateAudienceModelResponseTypeDef",
    "CreateConfiguredAudienceModelResponseTypeDef",
    "CreateTrainingDatasetResponseTypeDef",
    "EmptyResponseMetadataTypeDef",
    "GetAudienceModelResponseTypeDef",
    "GetConfiguredAudienceModelPolicyResponseTypeDef",
    "ListAudienceGenerationJobsResponseTypeDef",
    "ListAudienceModelsResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "PutConfiguredAudienceModelPolicyResponseTypeDef",
    "StartAudienceGenerationJobResponseTypeDef",
    "UpdateConfiguredAudienceModelResponseTypeDef",
    "DataSourceTypeDef",
    "ListAudienceExportJobsRequestListAudienceExportJobsPaginateTypeDef",
    "ListAudienceGenerationJobsRequestListAudienceGenerationJobsPaginateTypeDef",
    "ListAudienceModelsRequestListAudienceModelsPaginateTypeDef",
    "ListConfiguredAudienceModelsRequestListConfiguredAudienceModelsPaginateTypeDef",
    "ListTrainingDatasetsRequestListTrainingDatasetsPaginateTypeDef",
    "ListTrainingDatasetsResponseTypeDef",
    "ConfiguredAudienceModelOutputConfigTypeDef",
    "StartAudienceGenerationJobRequestRequestTypeDef",
    "AudienceQualityMetricsTypeDef",
    "ListAudienceExportJobsResponseTypeDef",
    "DatasetInputConfigTypeDef",
    "ConfiguredAudienceModelSummaryTypeDef",
    "CreateConfiguredAudienceModelRequestRequestTypeDef",
    "GetConfiguredAudienceModelResponseTypeDef",
    "UpdateConfiguredAudienceModelRequestRequestTypeDef",
    "GetAudienceGenerationJobResponseTypeDef",
    "DatasetTypeDef",
    "ListConfiguredAudienceModelsResponseTypeDef",
    "CreateTrainingDatasetRequestRequestTypeDef",
    "GetTrainingDatasetResponseTypeDef",
)

S3ConfigMapTypeDef = TypedDict(
    "S3ConfigMapTypeDef",
    {
        "s3Uri": str,
    },
)
AudienceSizeTypeDef = TypedDict(
    "AudienceSizeTypeDef",
    {
        "type": AudienceSizeTypeType,
        "value": int,
    },
)
StatusDetailsTypeDef = TypedDict(
    "StatusDetailsTypeDef",
    {
        "message": NotRequired[str],
        "statusCode": NotRequired[str],
    },
)
AudienceGenerationJobSummaryTypeDef = TypedDict(
    "AudienceGenerationJobSummaryTypeDef",
    {
        "audienceGenerationJobArn": str,
        "configuredAudienceModelArn": str,
        "createTime": datetime,
        "name": str,
        "status": AudienceGenerationJobStatusType,
        "updateTime": datetime,
        "collaborationId": NotRequired[str],
        "description": NotRequired[str],
        "startedBy": NotRequired[str],
    },
)
AudienceModelMetricTypeDef = TypedDict(
    "AudienceModelMetricTypeDef",
    {
        "forTopKItemPredictions": int,
        "type": AudienceModelMetricTypeType,
        "value": float,
    },
)
AudienceModelSummaryTypeDef = TypedDict(
    "AudienceModelSummaryTypeDef",
    {
        "audienceModelArn": str,
        "createTime": datetime,
        "name": str,
        "status": AudienceModelStatusType,
        "trainingDatasetArn": str,
        "updateTime": datetime,
        "description": NotRequired[str],
    },
)
AudienceSizeConfigTypeDef = TypedDict(
    "AudienceSizeConfigTypeDef",
    {
        "audienceSizeBins": Sequence[int],
        "audienceSizeType": AudienceSizeTypeType,
    },
)
ColumnSchemaTypeDef = TypedDict(
    "ColumnSchemaTypeDef",
    {
        "columnName": str,
        "columnTypes": Sequence[ColumnTypeType],
    },
)
TimestampTypeDef = Union[datetime, str]
ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)
GlueDataSourceTypeDef = TypedDict(
    "GlueDataSourceTypeDef",
    {
        "databaseName": str,
        "tableName": str,
        "catalogId": NotRequired[str],
    },
)
DeleteAudienceGenerationJobRequestRequestTypeDef = TypedDict(
    "DeleteAudienceGenerationJobRequestRequestTypeDef",
    {
        "audienceGenerationJobArn": str,
    },
)
DeleteAudienceModelRequestRequestTypeDef = TypedDict(
    "DeleteAudienceModelRequestRequestTypeDef",
    {
        "audienceModelArn": str,
    },
)
DeleteConfiguredAudienceModelPolicyRequestRequestTypeDef = TypedDict(
    "DeleteConfiguredAudienceModelPolicyRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
    },
)
DeleteConfiguredAudienceModelRequestRequestTypeDef = TypedDict(
    "DeleteConfiguredAudienceModelRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
    },
)
DeleteTrainingDatasetRequestRequestTypeDef = TypedDict(
    "DeleteTrainingDatasetRequestRequestTypeDef",
    {
        "trainingDatasetArn": str,
    },
)
GetAudienceGenerationJobRequestRequestTypeDef = TypedDict(
    "GetAudienceGenerationJobRequestRequestTypeDef",
    {
        "audienceGenerationJobArn": str,
    },
)
GetAudienceModelRequestRequestTypeDef = TypedDict(
    "GetAudienceModelRequestRequestTypeDef",
    {
        "audienceModelArn": str,
    },
)
GetConfiguredAudienceModelPolicyRequestRequestTypeDef = TypedDict(
    "GetConfiguredAudienceModelPolicyRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
    },
)
GetConfiguredAudienceModelRequestRequestTypeDef = TypedDict(
    "GetConfiguredAudienceModelRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
    },
)
GetTrainingDatasetRequestRequestTypeDef = TypedDict(
    "GetTrainingDatasetRequestRequestTypeDef",
    {
        "trainingDatasetArn": str,
    },
)
PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": NotRequired[int],
        "PageSize": NotRequired[int],
        "StartingToken": NotRequired[str],
    },
)
ListAudienceExportJobsRequestRequestTypeDef = TypedDict(
    "ListAudienceExportJobsRequestRequestTypeDef",
    {
        "audienceGenerationJobArn": NotRequired[str],
        "maxResults": NotRequired[int],
        "nextToken": NotRequired[str],
    },
)
ListAudienceGenerationJobsRequestRequestTypeDef = TypedDict(
    "ListAudienceGenerationJobsRequestRequestTypeDef",
    {
        "collaborationId": NotRequired[str],
        "configuredAudienceModelArn": NotRequired[str],
        "maxResults": NotRequired[int],
        "nextToken": NotRequired[str],
    },
)
ListAudienceModelsRequestRequestTypeDef = TypedDict(
    "ListAudienceModelsRequestRequestTypeDef",
    {
        "maxResults": NotRequired[int],
        "nextToken": NotRequired[str],
    },
)
ListConfiguredAudienceModelsRequestRequestTypeDef = TypedDict(
    "ListConfiguredAudienceModelsRequestRequestTypeDef",
    {
        "maxResults": NotRequired[int],
        "nextToken": NotRequired[str],
    },
)
ListTagsForResourceRequestRequestTypeDef = TypedDict(
    "ListTagsForResourceRequestRequestTypeDef",
    {
        "resourceArn": str,
    },
)
ListTrainingDatasetsRequestRequestTypeDef = TypedDict(
    "ListTrainingDatasetsRequestRequestTypeDef",
    {
        "maxResults": NotRequired[int],
        "nextToken": NotRequired[str],
    },
)
TrainingDatasetSummaryTypeDef = TypedDict(
    "TrainingDatasetSummaryTypeDef",
    {
        "createTime": datetime,
        "name": str,
        "status": Literal["ACTIVE"],
        "trainingDatasetArn": str,
        "updateTime": datetime,
        "description": NotRequired[str],
    },
)
PutConfiguredAudienceModelPolicyRequestRequestTypeDef = TypedDict(
    "PutConfiguredAudienceModelPolicyRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
        "configuredAudienceModelPolicy": str,
        "policyExistenceCondition": NotRequired[PolicyExistenceConditionType],
        "previousPolicyHash": NotRequired[str],
    },
)
TagResourceRequestRequestTypeDef = TypedDict(
    "TagResourceRequestRequestTypeDef",
    {
        "resourceArn": str,
        "tags": Mapping[str, str],
    },
)
UntagResourceRequestRequestTypeDef = TypedDict(
    "UntagResourceRequestRequestTypeDef",
    {
        "resourceArn": str,
        "tagKeys": Sequence[str],
    },
)
AudienceDestinationTypeDef = TypedDict(
    "AudienceDestinationTypeDef",
    {
        "s3Destination": S3ConfigMapTypeDef,
    },
)
AudienceGenerationJobDataSourceTypeDef = TypedDict(
    "AudienceGenerationJobDataSourceTypeDef",
    {
        "dataSource": S3ConfigMapTypeDef,
        "roleArn": str,
    },
)
RelevanceMetricTypeDef = TypedDict(
    "RelevanceMetricTypeDef",
    {
        "audienceSize": AudienceSizeTypeDef,
        "score": NotRequired[float],
    },
)
StartAudienceExportJobRequestRequestTypeDef = TypedDict(
    "StartAudienceExportJobRequestRequestTypeDef",
    {
        "audienceGenerationJobArn": str,
        "audienceSize": AudienceSizeTypeDef,
        "name": str,
        "description": NotRequired[str],
    },
)
AudienceExportJobSummaryTypeDef = TypedDict(
    "AudienceExportJobSummaryTypeDef",
    {
        "audienceGenerationJobArn": str,
        "audienceSize": AudienceSizeTypeDef,
        "createTime": datetime,
        "name": str,
        "status": AudienceExportJobStatusType,
        "updateTime": datetime,
        "description": NotRequired[str],
        "outputLocation": NotRequired[str],
        "statusDetails": NotRequired[StatusDetailsTypeDef],
    },
)
CreateAudienceModelRequestRequestTypeDef = TypedDict(
    "CreateAudienceModelRequestRequestTypeDef",
    {
        "name": str,
        "trainingDatasetArn": str,
        "description": NotRequired[str],
        "kmsKeyArn": NotRequired[str],
        "tags": NotRequired[Mapping[str, str]],
        "trainingDataEndTime": NotRequired[TimestampTypeDef],
        "trainingDataStartTime": NotRequired[TimestampTypeDef],
    },
)
CreateAudienceModelResponseTypeDef = TypedDict(
    "CreateAudienceModelResponseTypeDef",
    {
        "audienceModelArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateConfiguredAudienceModelResponseTypeDef = TypedDict(
    "CreateConfiguredAudienceModelResponseTypeDef",
    {
        "configuredAudienceModelArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateTrainingDatasetResponseTypeDef = TypedDict(
    "CreateTrainingDatasetResponseTypeDef",
    {
        "trainingDatasetArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
EmptyResponseMetadataTypeDef = TypedDict(
    "EmptyResponseMetadataTypeDef",
    {
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetAudienceModelResponseTypeDef = TypedDict(
    "GetAudienceModelResponseTypeDef",
    {
        "audienceModelArn": str,
        "createTime": datetime,
        "description": str,
        "kmsKeyArn": str,
        "metrics": List[AudienceModelMetricTypeDef],
        "name": str,
        "status": AudienceModelStatusType,
        "statusDetails": StatusDetailsTypeDef,
        "tags": Dict[str, str],
        "trainingDataEndTime": datetime,
        "trainingDataStartTime": datetime,
        "trainingDatasetArn": str,
        "updateTime": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetConfiguredAudienceModelPolicyResponseTypeDef = TypedDict(
    "GetConfiguredAudienceModelPolicyResponseTypeDef",
    {
        "configuredAudienceModelArn": str,
        "configuredAudienceModelPolicy": str,
        "policyHash": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListAudienceGenerationJobsResponseTypeDef = TypedDict(
    "ListAudienceGenerationJobsResponseTypeDef",
    {
        "audienceGenerationJobs": List[AudienceGenerationJobSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListAudienceModelsResponseTypeDef = TypedDict(
    "ListAudienceModelsResponseTypeDef",
    {
        "audienceModels": List[AudienceModelSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef",
    {
        "tags": Dict[str, str],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
PutConfiguredAudienceModelPolicyResponseTypeDef = TypedDict(
    "PutConfiguredAudienceModelPolicyResponseTypeDef",
    {
        "configuredAudienceModelPolicy": str,
        "policyHash": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
StartAudienceGenerationJobResponseTypeDef = TypedDict(
    "StartAudienceGenerationJobResponseTypeDef",
    {
        "audienceGenerationJobArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
UpdateConfiguredAudienceModelResponseTypeDef = TypedDict(
    "UpdateConfiguredAudienceModelResponseTypeDef",
    {
        "configuredAudienceModelArn": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
DataSourceTypeDef = TypedDict(
    "DataSourceTypeDef",
    {
        "glueDataSource": GlueDataSourceTypeDef,
    },
)
ListAudienceExportJobsRequestListAudienceExportJobsPaginateTypeDef = TypedDict(
    "ListAudienceExportJobsRequestListAudienceExportJobsPaginateTypeDef",
    {
        "audienceGenerationJobArn": NotRequired[str],
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
ListAudienceGenerationJobsRequestListAudienceGenerationJobsPaginateTypeDef = TypedDict(
    "ListAudienceGenerationJobsRequestListAudienceGenerationJobsPaginateTypeDef",
    {
        "collaborationId": NotRequired[str],
        "configuredAudienceModelArn": NotRequired[str],
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
ListAudienceModelsRequestListAudienceModelsPaginateTypeDef = TypedDict(
    "ListAudienceModelsRequestListAudienceModelsPaginateTypeDef",
    {
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
ListConfiguredAudienceModelsRequestListConfiguredAudienceModelsPaginateTypeDef = TypedDict(
    "ListConfiguredAudienceModelsRequestListConfiguredAudienceModelsPaginateTypeDef",
    {
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
ListTrainingDatasetsRequestListTrainingDatasetsPaginateTypeDef = TypedDict(
    "ListTrainingDatasetsRequestListTrainingDatasetsPaginateTypeDef",
    {
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
ListTrainingDatasetsResponseTypeDef = TypedDict(
    "ListTrainingDatasetsResponseTypeDef",
    {
        "nextToken": str,
        "trainingDatasets": List[TrainingDatasetSummaryTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
ConfiguredAudienceModelOutputConfigTypeDef = TypedDict(
    "ConfiguredAudienceModelOutputConfigTypeDef",
    {
        "destination": AudienceDestinationTypeDef,
        "roleArn": str,
    },
)
StartAudienceGenerationJobRequestRequestTypeDef = TypedDict(
    "StartAudienceGenerationJobRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
        "name": str,
        "seedAudience": AudienceGenerationJobDataSourceTypeDef,
        "collaborationId": NotRequired[str],
        "description": NotRequired[str],
        "includeSeedInOutput": NotRequired[bool],
        "tags": NotRequired[Mapping[str, str]],
    },
)
AudienceQualityMetricsTypeDef = TypedDict(
    "AudienceQualityMetricsTypeDef",
    {
        "relevanceMetrics": List[RelevanceMetricTypeDef],
    },
)
ListAudienceExportJobsResponseTypeDef = TypedDict(
    "ListAudienceExportJobsResponseTypeDef",
    {
        "audienceExportJobs": List[AudienceExportJobSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
DatasetInputConfigTypeDef = TypedDict(
    "DatasetInputConfigTypeDef",
    {
        "dataSource": DataSourceTypeDef,
        "schema": Sequence[ColumnSchemaTypeDef],
    },
)
ConfiguredAudienceModelSummaryTypeDef = TypedDict(
    "ConfiguredAudienceModelSummaryTypeDef",
    {
        "audienceModelArn": str,
        "configuredAudienceModelArn": str,
        "createTime": datetime,
        "name": str,
        "outputConfig": ConfiguredAudienceModelOutputConfigTypeDef,
        "status": Literal["ACTIVE"],
        "updateTime": datetime,
        "description": NotRequired[str],
    },
)
CreateConfiguredAudienceModelRequestRequestTypeDef = TypedDict(
    "CreateConfiguredAudienceModelRequestRequestTypeDef",
    {
        "audienceModelArn": str,
        "name": str,
        "outputConfig": ConfiguredAudienceModelOutputConfigTypeDef,
        "sharedAudienceMetrics": Sequence[SharedAudienceMetricsType],
        "audienceSizeConfig": NotRequired[AudienceSizeConfigTypeDef],
        "childResourceTagOnCreatePolicy": NotRequired[TagOnCreatePolicyType],
        "description": NotRequired[str],
        "minMatchingSeedSize": NotRequired[int],
        "tags": NotRequired[Mapping[str, str]],
    },
)
GetConfiguredAudienceModelResponseTypeDef = TypedDict(
    "GetConfiguredAudienceModelResponseTypeDef",
    {
        "audienceModelArn": str,
        "audienceSizeConfig": AudienceSizeConfigTypeDef,
        "childResourceTagOnCreatePolicy": TagOnCreatePolicyType,
        "configuredAudienceModelArn": str,
        "createTime": datetime,
        "description": str,
        "minMatchingSeedSize": int,
        "name": str,
        "outputConfig": ConfiguredAudienceModelOutputConfigTypeDef,
        "sharedAudienceMetrics": List[SharedAudienceMetricsType],
        "status": Literal["ACTIVE"],
        "tags": Dict[str, str],
        "updateTime": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
UpdateConfiguredAudienceModelRequestRequestTypeDef = TypedDict(
    "UpdateConfiguredAudienceModelRequestRequestTypeDef",
    {
        "configuredAudienceModelArn": str,
        "audienceModelArn": NotRequired[str],
        "audienceSizeConfig": NotRequired[AudienceSizeConfigTypeDef],
        "description": NotRequired[str],
        "minMatchingSeedSize": NotRequired[int],
        "outputConfig": NotRequired[ConfiguredAudienceModelOutputConfigTypeDef],
        "sharedAudienceMetrics": NotRequired[Sequence[SharedAudienceMetricsType]],
    },
)
GetAudienceGenerationJobResponseTypeDef = TypedDict(
    "GetAudienceGenerationJobResponseTypeDef",
    {
        "audienceGenerationJobArn": str,
        "collaborationId": str,
        "configuredAudienceModelArn": str,
        "createTime": datetime,
        "description": str,
        "includeSeedInOutput": bool,
        "metrics": AudienceQualityMetricsTypeDef,
        "name": str,
        "seedAudience": AudienceGenerationJobDataSourceTypeDef,
        "startedBy": str,
        "status": AudienceGenerationJobStatusType,
        "statusDetails": StatusDetailsTypeDef,
        "tags": Dict[str, str],
        "updateTime": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
DatasetTypeDef = TypedDict(
    "DatasetTypeDef",
    {
        "inputConfig": DatasetInputConfigTypeDef,
        "type": Literal["INTERACTIONS"],
    },
)
ListConfiguredAudienceModelsResponseTypeDef = TypedDict(
    "ListConfiguredAudienceModelsResponseTypeDef",
    {
        "configuredAudienceModels": List[ConfiguredAudienceModelSummaryTypeDef],
        "nextToken": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
CreateTrainingDatasetRequestRequestTypeDef = TypedDict(
    "CreateTrainingDatasetRequestRequestTypeDef",
    {
        "name": str,
        "roleArn": str,
        "trainingData": Sequence[DatasetTypeDef],
        "description": NotRequired[str],
        "tags": NotRequired[Mapping[str, str]],
    },
)
GetTrainingDatasetResponseTypeDef = TypedDict(
    "GetTrainingDatasetResponseTypeDef",
    {
        "createTime": datetime,
        "description": str,
        "name": str,
        "roleArn": str,
        "status": Literal["ACTIVE"],
        "tags": Dict[str, str],
        "trainingData": List[DatasetTypeDef],
        "trainingDatasetArn": str,
        "updateTime": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)



"""
Type annotations for cleanroomsml service client.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/)

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_cleanroomsml.client import cleanroomsmlClient

    session = Session()
    client: cleanroomsmlClient = session.client("cleanroomsml")
    ```
"""

import sys
from typing import Any, Dict, Mapping, Sequence, Type, overload

from botocore.client import BaseClient, ClientMeta

from .literals import PolicyExistenceConditionType, SharedAudienceMetricsType, TagOnCreatePolicyType
from .paginator import (
    ListAudienceExportJobsPaginator,
    ListAudienceGenerationJobsPaginator,
    ListAudienceModelsPaginator,
    ListConfiguredAudienceModelsPaginator,
    ListTrainingDatasetsPaginator,
)
from .type_defs import (
    AudienceGenerationJobDataSourceTypeDef,
    AudienceSizeConfigTypeDef,
    AudienceSizeTypeDef,
    ConfiguredAudienceModelOutputConfigTypeDef,
    CreateAudienceModelResponseTypeDef,
    CreateConfiguredAudienceModelResponseTypeDef,
    CreateTrainingDatasetResponseTypeDef,
    DatasetTypeDef,
    EmptyResponseMetadataTypeDef,
    GetAudienceGenerationJobResponseTypeDef,
    GetAudienceModelResponseTypeDef,
    GetConfiguredAudienceModelPolicyResponseTypeDef,
    GetConfiguredAudienceModelResponseTypeDef,
    GetTrainingDatasetResponseTypeDef,
    ListAudienceExportJobsResponseTypeDef,
    ListAudienceGenerationJobsResponseTypeDef,
    ListAudienceModelsResponseTypeDef,
    ListConfiguredAudienceModelsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTrainingDatasetsResponseTypeDef,
    PutConfiguredAudienceModelPolicyResponseTypeDef,
    StartAudienceGenerationJobResponseTypeDef,
    TimestampTypeDef,
    UpdateConfiguredAudienceModelResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("cleanroomsmlClient",)


class BotocoreClientError(Exception):
    MSG_TEMPLATE: str

    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str


class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class cleanroomsmlClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        cleanroomsmlClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.exceptions)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        Check if an operation can be paginated.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.can_paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#can_paginate)
        """

    def close(self) -> None:
        """
        Closes underlying endpoint connections.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.close)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#close)
        """

    def create_audience_model(
        self,
        *,
        name: str,
        trainingDatasetArn: str,
        description: str = ...,
        kmsKeyArn: str = ...,
        tags: Mapping[str, str] = ...,
        trainingDataEndTime: TimestampTypeDef = ...,
        trainingDataStartTime: TimestampTypeDef = ...
    ) -> CreateAudienceModelResponseTypeDef:
        """
        Defines the information necessary to create an audience model.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.create_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#create_audience_model)
        """

    def create_configured_audience_model(
        self,
        *,
        audienceModelArn: str,
        name: str,
        outputConfig: ConfiguredAudienceModelOutputConfigTypeDef,
        sharedAudienceMetrics: Sequence[SharedAudienceMetricsType],
        audienceSizeConfig: AudienceSizeConfigTypeDef = ...,
        childResourceTagOnCreatePolicy: TagOnCreatePolicyType = ...,
        description: str = ...,
        minMatchingSeedSize: int = ...,
        tags: Mapping[str, str] = ...
    ) -> CreateConfiguredAudienceModelResponseTypeDef:
        """
        Defines the information necessary to create a configured audience model.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.create_configured_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#create_configured_audience_model)
        """

    def create_training_dataset(
        self,
        *,
        name: str,
        roleArn: str,
        trainingData: Sequence[DatasetTypeDef],
        description: str = ...,
        tags: Mapping[str, str] = ...
    ) -> CreateTrainingDatasetResponseTypeDef:
        """
        Defines the information necessary to create a training dataset, or seed
        audience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.create_training_dataset)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#create_training_dataset)
        """

    def delete_audience_generation_job(
        self, *, audienceGenerationJobArn: str
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified audience generation job, and removes all data associated
        with the
        job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.delete_audience_generation_job)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#delete_audience_generation_job)
        """

    def delete_audience_model(self, *, audienceModelArn: str) -> EmptyResponseMetadataTypeDef:
        """
        Specifies an audience model that you want to delete.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.delete_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#delete_audience_model)
        """

    def delete_configured_audience_model(
        self, *, configuredAudienceModelArn: str
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified configured audience model.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.delete_configured_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#delete_configured_audience_model)
        """

    def delete_configured_audience_model_policy(
        self, *, configuredAudienceModelArn: str
    ) -> EmptyResponseMetadataTypeDef:
        """
        Deletes the specified configured audience model policy.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.delete_configured_audience_model_policy)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#delete_configured_audience_model_policy)
        """

    def delete_training_dataset(self, *, trainingDatasetArn: str) -> EmptyResponseMetadataTypeDef:
        """
        Specifies a training dataset that you want to delete.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.delete_training_dataset)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#delete_training_dataset)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        Generate a presigned url given a client, its method, and arguments.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#generate_presigned_url)
        """

    def get_audience_generation_job(
        self, *, audienceGenerationJobArn: str
    ) -> GetAudienceGenerationJobResponseTypeDef:
        """
        Returns information about an audience generation job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_audience_generation_job)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_audience_generation_job)
        """

    def get_audience_model(self, *, audienceModelArn: str) -> GetAudienceModelResponseTypeDef:
        """
        Returns information about an audience model See also: [AWS API
        Documentation](https://docs.aws.amazon.com/goto/WebAPI/cleanroomsml-2023-09-06/GetAudienceModel).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_audience_model)
        """

    def get_configured_audience_model(
        self, *, configuredAudienceModelArn: str
    ) -> GetConfiguredAudienceModelResponseTypeDef:
        """
        Returns information about a specified configured audience model.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_configured_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_configured_audience_model)
        """

    def get_configured_audience_model_policy(
        self, *, configuredAudienceModelArn: str
    ) -> GetConfiguredAudienceModelPolicyResponseTypeDef:
        """
        Returns information about a configured audience model policy.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_configured_audience_model_policy)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_configured_audience_model_policy)
        """

    def get_training_dataset(self, *, trainingDatasetArn: str) -> GetTrainingDatasetResponseTypeDef:
        """
        Returns information about a training dataset.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_training_dataset)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_training_dataset)
        """

    def list_audience_export_jobs(
        self, *, audienceGenerationJobArn: str = ..., maxResults: int = ..., nextToken: str = ...
    ) -> ListAudienceExportJobsResponseTypeDef:
        """
        Returns a list of the audience export jobs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.list_audience_export_jobs)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#list_audience_export_jobs)
        """

    def list_audience_generation_jobs(
        self,
        *,
        collaborationId: str = ...,
        configuredAudienceModelArn: str = ...,
        maxResults: int = ...,
        nextToken: str = ...
    ) -> ListAudienceGenerationJobsResponseTypeDef:
        """
        Returns a list of audience generation jobs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.list_audience_generation_jobs)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#list_audience_generation_jobs)
        """

    def list_audience_models(
        self, *, maxResults: int = ..., nextToken: str = ...
    ) -> ListAudienceModelsResponseTypeDef:
        """
        Returns a list of audience models.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.list_audience_models)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#list_audience_models)
        """

    def list_configured_audience_models(
        self, *, maxResults: int = ..., nextToken: str = ...
    ) -> ListConfiguredAudienceModelsResponseTypeDef:
        """
        Returns a list of the configured audience models.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.list_configured_audience_models)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#list_configured_audience_models)
        """

    def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        Returns a list of tags for a provided resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.list_tags_for_resource)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#list_tags_for_resource)
        """

    def list_training_datasets(
        self, *, maxResults: int = ..., nextToken: str = ...
    ) -> ListTrainingDatasetsResponseTypeDef:
        """
        Returns a list of training datasets.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.list_training_datasets)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#list_training_datasets)
        """

    def put_configured_audience_model_policy(
        self,
        *,
        configuredAudienceModelArn: str,
        configuredAudienceModelPolicy: str,
        policyExistenceCondition: PolicyExistenceConditionType = ...,
        previousPolicyHash: str = ...
    ) -> PutConfiguredAudienceModelPolicyResponseTypeDef:
        """
        Create or update the resource policy for a configured audience model.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.put_configured_audience_model_policy)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#put_configured_audience_model_policy)
        """

    def start_audience_export_job(
        self,
        *,
        audienceGenerationJobArn: str,
        audienceSize: AudienceSizeTypeDef,
        name: str,
        description: str = ...
    ) -> EmptyResponseMetadataTypeDef:
        """
        Export an audience of a specified size after you have generated an audience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.start_audience_export_job)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#start_audience_export_job)
        """

    def start_audience_generation_job(
        self,
        *,
        configuredAudienceModelArn: str,
        name: str,
        seedAudience: AudienceGenerationJobDataSourceTypeDef,
        collaborationId: str = ...,
        description: str = ...,
        includeSeedInOutput: bool = ...,
        tags: Mapping[str, str] = ...
    ) -> StartAudienceGenerationJobResponseTypeDef:
        """
        Information necessary to start the audience generation job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.start_audience_generation_job)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#start_audience_generation_job)
        """

    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
        """
        Adds metadata tags to a specified resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.tag_resource)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#tag_resource)
        """

    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
        """
        Removes metadata tags from a specified resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.untag_resource)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#untag_resource)
        """

    def update_configured_audience_model(
        self,
        *,
        configuredAudienceModelArn: str,
        audienceModelArn: str = ...,
        audienceSizeConfig: AudienceSizeConfigTypeDef = ...,
        description: str = ...,
        minMatchingSeedSize: int = ...,
        outputConfig: ConfiguredAudienceModelOutputConfigTypeDef = ...,
        sharedAudienceMetrics: Sequence[SharedAudienceMetricsType] = ...
    ) -> UpdateConfiguredAudienceModelResponseTypeDef:
        """
        Provides the information necessary to update a configured audience model.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.update_configured_audience_model)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#update_configured_audience_model)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_audience_export_jobs"]
    ) -> ListAudienceExportJobsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_paginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_audience_generation_jobs"]
    ) -> ListAudienceGenerationJobsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_paginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_audience_models"]
    ) -> ListAudienceModelsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_paginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_configured_audience_models"]
    ) -> ListConfiguredAudienceModelsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_paginator)
        """

    @overload
    def get_paginator(
        self, operation_name: Literal["list_training_datasets"]
    ) -> ListTrainingDatasetsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Client.get_paginator)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/client/#get_paginator)
        """



"""
Main interface for cleanroomsml service.

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_cleanroomsml import (
        Client,
        ListAudienceExportJobsPaginator,
        ListAudienceGenerationJobsPaginator,
        ListAudienceModelsPaginator,
        ListConfiguredAudienceModelsPaginator,
        ListTrainingDatasetsPaginator,
        cleanroomsmlClient,
    )

    session = Session()
    client: cleanroomsmlClient = session.client("cleanroomsml")

    list_audience_export_jobs_paginator: ListAudienceExportJobsPaginator = client.get_paginator("list_audience_export_jobs")
    list_audience_generation_jobs_paginator: ListAudienceGenerationJobsPaginator = client.get_paginator("list_audience_generation_jobs")
    list_audience_models_paginator: ListAudienceModelsPaginator = client.get_paginator("list_audience_models")
    list_configured_audience_models_paginator: ListConfiguredAudienceModelsPaginator = client.get_paginator("list_configured_audience_models")
    list_training_datasets_paginator: ListTrainingDatasetsPaginator = client.get_paginator("list_training_datasets")
    ```
"""

from .client import cleanroomsmlClient
from .paginator import (
    ListAudienceExportJobsPaginator,
    ListAudienceGenerationJobsPaginator,
    ListAudienceModelsPaginator,
    ListConfiguredAudienceModelsPaginator,
    ListTrainingDatasetsPaginator,
)

Client = cleanroomsmlClient


__all__ = (
    "Client",
    "ListAudienceExportJobsPaginator",
    "ListAudienceGenerationJobsPaginator",
    "ListAudienceModelsPaginator",
    "ListConfiguredAudienceModelsPaginator",
    "ListTrainingDatasetsPaginator",
    "cleanroomsmlClient",
)



"""
Type annotations for cleanroomsml service client paginators.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from mypy_boto3_cleanroomsml.client import cleanroomsmlClient
    from mypy_boto3_cleanroomsml.paginator import (
        ListAudienceExportJobsPaginator,
        ListAudienceGenerationJobsPaginator,
        ListAudienceModelsPaginator,
        ListConfiguredAudienceModelsPaginator,
        ListTrainingDatasetsPaginator,
    )

    session = Session()
    client: cleanroomsmlClient = session.client("cleanroomsml")

    list_audience_export_jobs_paginator: ListAudienceExportJobsPaginator = client.get_paginator("list_audience_export_jobs")
    list_audience_generation_jobs_paginator: ListAudienceGenerationJobsPaginator = client.get_paginator("list_audience_generation_jobs")
    list_audience_models_paginator: ListAudienceModelsPaginator = client.get_paginator("list_audience_models")
    list_configured_audience_models_paginator: ListConfiguredAudienceModelsPaginator = client.get_paginator("list_configured_audience_models")
    list_training_datasets_paginator: ListTrainingDatasetsPaginator = client.get_paginator("list_training_datasets")
    ```
"""

from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListAudienceExportJobsResponseTypeDef,
    ListAudienceGenerationJobsResponseTypeDef,
    ListAudienceModelsResponseTypeDef,
    ListConfiguredAudienceModelsResponseTypeDef,
    ListTrainingDatasetsResponseTypeDef,
    PaginatorConfigTypeDef,
)

__all__ = (
    "ListAudienceExportJobsPaginator",
    "ListAudienceGenerationJobsPaginator",
    "ListAudienceModelsPaginator",
    "ListConfiguredAudienceModelsPaginator",
    "ListTrainingDatasetsPaginator",
)

_ItemTypeDef = TypeVar("_ItemTypeDef")

class _PageIterator(Generic[_ItemTypeDef], PageIterator):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """

class ListAudienceExportJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListAudienceExportJobs)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listaudienceexportjobspaginator)
    """

    def paginate(
        self, *, audienceGenerationJobArn: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListAudienceExportJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListAudienceExportJobs.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listaudienceexportjobspaginator)
        """

class ListAudienceGenerationJobsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListAudienceGenerationJobs)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listaudiencegenerationjobspaginator)
    """

    def paginate(
        self,
        *,
        collaborationId: str = ...,
        configuredAudienceModelArn: str = ...,
        PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListAudienceGenerationJobsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListAudienceGenerationJobs.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listaudiencegenerationjobspaginator)
        """

class ListAudienceModelsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListAudienceModels)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listaudiencemodelspaginator)
    """

    def paginate(
        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListAudienceModelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListAudienceModels.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listaudiencemodelspaginator)
        """

class ListConfiguredAudienceModelsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListConfiguredAudienceModels)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listconfiguredaudiencemodelspaginator)
    """

    def paginate(
        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListConfiguredAudienceModelsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListConfiguredAudienceModels.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listconfiguredaudiencemodelspaginator)
        """

class ListTrainingDatasetsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListTrainingDatasets)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listtrainingdatasetspaginator)
    """

    def paginate(
        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
    ) -> _PageIterator[ListTrainingDatasetsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cleanroomsml.html#cleanroomsml.Paginator.ListTrainingDatasets.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cleanroomsml/paginators/#listtrainingdatasetspaginator)
        """
